# © Copyright [2016 - 2020] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (“Micro Focus”) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions
# contained herein. The information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items are licensed
# to the U.S. Government under vendor's standard commercial license.

DOCKER_SYSCONFIG="/etc/sysconfig/docker"
if [ ! -f $DOCKER_SYSCONFIG ]; then
	logger -t cis "Docker not configured. Exiting...\n"
	exit 1;
fi

DOC_OPTS=`grep "^DOCKER_OPTS" $DOCKER_SYSCONFIG`
if [ $? -ne 0 ]; then
	echo "DOCKER_OPTS=\"--iptables=false\"" >> $DOCKER_SYSCONFIG
	logger -t cis "Docker OPTS iptables not found, so added to docker config file.\n"
else
	#DOCKER_OPTS found. checking for iptables options
	echo $DOC_OPTS | grep '\-\-iptables=' > /dev/null
	if [ $? -ne 0 ]; then
		#iptables option not found so append to the existing options."
		NEW_DOC_OPTS=`echo $DOC_OPTS | sed  's/\(.*\)"$/\1 --iptables=false"/'`
	fi

	echo $DOC_OPTS | grep "\-\-iptables=false" > /dev/null
	if [ $? -eq 0 ]; then
		#Already false. No change required.
		exit 0;
	fi
	echo $DOC_OPTS | grep "\-\-iptables=true" > /dev/null
	if [ $? -eq 0 ]; then
		#iptables option was true. changinf it to false.
		NEW_DOC_OPTS=`echo $DOC_OPTS | sed  's/\(--iptables=\)true/\1false/'`
	fi
	#Updating the options to config file
	sed -i "s/\(^DOCKER_OPTS=\).*$/$NEW_DOC_OPTS/" $DOCKER_SYSCONFIG
	if [ $? -ne 0 ]; then
		logger -t cis "Failed to update docker options.\n"
		exit 1;
	fi
fi
systemctl restart docker
if [ $? -ne 0 ]; then
	logger -t cis "Failed to restart docker.\n"
	exit 1;
fi
exit 0
